Use an enum class for Marker.
[libdcp.git] / src / dcp.h
index 34611fb73b70ea931f94b569724cf4b4443282d5..73f154c707a78c1f60da06a7255c9d0b7dffa926 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2012-2014 Carl Hetherington <cth@carlh.net>
+    Copyright (C) 2012-2020 Carl Hetherington <cth@carlh.net>
 
     This file is part of libdcp.
 
 #ifndef LIBDCP_DCP_H
 #define LIBDCP_DCP_H
 
+#include "compose.hpp"
 #include "types.h"
 #include "util.h"
 #include "certificate.h"
 #include "metadata.h"
 #include "name_format.h"
 #include "verify.h"
-#include <boost/shared_ptr.hpp>
+#include "version.h"
+#include <memory>
 #include <boost/signals2.hpp>
 #include <string>
 #include <vector>
@@ -62,11 +64,10 @@ class PKL;
 class Content;
 class Reel;
 class CPL;
-class XMLMetadata;
 class CertificateChain;
 class DecryptedKDM;
 class Asset;
-class DCPReadError;
+class ReadError;
 
 /** @class DCP
  *  @brief A class to create or read a DCP.
@@ -90,7 +91,7 @@ public:
         *  as stereoscopic if the monoscopic load fails; fixes problems some 3D DCPs that (I think)
         *  have an incorrect descriptor in their MXF.
         */
-       void read (std::list<VerificationNote>* notes = 0, bool ignore_incorrect_picture_mxf_type = false);
+       void read (std::vector<VerificationNote>* notes = 0, bool ignore_incorrect_picture_mxf_type = false);
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -100,10 +101,10 @@ public:
         */
        bool equals (DCP const & other, EqualityOptions options, NoteHandler note) const;
 
-       void add (boost::shared_ptr<CPL> cpl);
+       void add (std::shared_ptr<CPL> cpl);
 
-       std::list<boost::shared_ptr<CPL> > cpls () const;
-       std::list<boost::shared_ptr<Asset> > assets (bool ignore_unresolved = false) const;
+       std::vector<std::shared_ptr<CPL>> cpls () const;
+       std::vector<std::shared_ptr<Asset>> assets (bool ignore_unresolved = false) const;
 
        bool encrypted () const;
 
@@ -111,12 +112,15 @@ public:
 
        void write_xml (
                Standard standard,
-               XMLMetadata metadata = XMLMetadata (),
-               boost::shared_ptr<const CertificateChain> signer = boost::shared_ptr<const CertificateChain> (),
+               std::string issuer = String::compose("libdcp %1", dcp::version),
+               std::string creator = String::compose("libdcp %1", dcp::version),
+               std::string issue_date = LocalTime().as_string(),
+               std::string annotation_text = String::compose("Created by libdcp %1", dcp::version),
+               std::shared_ptr<const CertificateChain> signer = std::shared_ptr<const CertificateChain> (),
                NameFormat name_format = NameFormat("%t")
        );
 
-       void resolve_refs (std::list<boost::shared_ptr<Asset> > assets);
+       void resolve_refs (std::vector<std::shared_ptr<Asset>> assets);
 
        /** @return Standard of a DCP that was read in */
        boost::optional<Standard> standard () const {
@@ -128,12 +132,16 @@ public:
        }
 
        /** @return PKLs if this DCP was read from an existing one, or if write_xml() has been called on it.
*  If neither is true, this method returns an empty list.
         */
-       std::list<boost::shared_ptr<PKL> > pkls () const {
+       std::vector<std::shared_ptr<PKL>> pkls () const {
                return _pkls;
        }
 
+       boost::optional<boost::filesystem::path> asset_map_path () {
+               return _asset_map;
+       }
+
        static std::vector<boost::filesystem::path> directories_from_files (std::vector<boost::filesystem::path> files);
 
 private:
@@ -144,13 +152,19 @@ private:
         *  @param pkl_uuid UUID of our PKL.
         *  @param pkl_path Pathname of our PKL file.
         */
-       void write_assetmap (Standard standard, std::string pkl_uuid, boost::filesystem::path pkl_path, XMLMetadata metadata) const;
+       void write_assetmap (
+               Standard standard, std::string pkl_uuid, boost::filesystem::path pkl_path,
+               std::string issuer, std::string creator, std::string issue_date, std::string annotation_text
+               ) const;
 
-       /** the directory that we are writing to */
+       /** The directory that we are writing to */
        boost::filesystem::path _directory;
-       /** the CPLs that make up this DCP */
-       std::list<boost::shared_ptr<CPL> > _cpls;
-       std::list<boost::shared_ptr<PKL> > _pkls;
+       /** The CPLs that make up this DCP */
+       std::vector<std::shared_ptr<CPL>> _cpls;
+       /** The PKLs that make up this DCP */
+       std::vector<std::shared_ptr<PKL>> _pkls;
+       /** File that the ASSETMAP was read from or last written to */
+       mutable boost::optional<boost::filesystem::path> _asset_map;
 
        /** Standard of DCP that was read in */
        boost::optional<Standard> _standard;
@@ -128,12 +132,16 @@ public:
 
        /** @return PKLs if this DCP was read from an existing one, or if write_xml() has been called on it.
-        *  If neither is true, this method returns an empty list.
+        *  If neither is true, this method returns an empty vector.
         */